@@ -377,17 +377,17 @@ def newapkbuild(args):
 
 def kconfig(args):
     if args.action_kconfig == "check":
+        details = args.kconfig_check_details
+        # Build the components list from cli arguments (--waydroid etc.)
+        components_list = []
+        for name in pmb.parse.kconfig.get_all_component_names():
+            if getattr(args, f"kconfig_check_{name}"):
+                components_list += [name]
+
         # Handle passing a file directly
         if args.file:
-            if pmb.parse.kconfig.check_file(args.package,
-                                            waydroid=args.waydroid,
-                                            nftables=args.nftables,
-                                            containers=args.containers,
-                                            zram=args.zram,
-                                            netboot=args.netboot,
-                                            community=args.community,
-                                            uefi=args.uefi,
-                                            details=True):
+            if pmb.parse.kconfig.check_file(args.package, components_list,
+                                            details=details):
                 logging.info("kconfig check succeeded!")
                 return
             raise RuntimeError("kconfig check failed!")
@@ -414,17 +414,8 @@ def kconfig(args):
                 if "!pmb:kconfigcheck" in apkbuild["options"]:
                     skipped += 1
                     continue
-            if not pmb.parse.kconfig.check(
-                    args, package,
-                    force_waydroid_check=args.waydroid,
-                    force_iwd_check=args.iwd,
-                    force_nftables_check=args.nftables,
-                    force_containers_check=args.containers,
-                    force_zram_check=args.zram,
-                    force_netboot_check=args.netboot,
-                    force_community_check=args.community,
-                    force_uefi_check=args.uefi,
-                    details=True):
+            if not pmb.parse.kconfig.check(args, package, components_list,
+                                           details=details):
                 error = True
 
         # At least one failure
@@ -540,14 +531,16 @@ def work_migrate(args):
 
 
 def log(args):
+    log_testsuite = f"{args.work}/log_testsuite.txt"
+
     if args.clear_log:
         pmb.helpers.run.user(args, ["truncate", "-s", "0", args.log])
+        pmb.helpers.run.user(args, ["truncate", "-s", "0", log_testsuite])
 
     cmd = ["tail", "-n", args.lines, "-F"]
 
     # Follow the testsuite's log file too if it exists. It will be created when
     # starting a test case that writes to it (git -C test grep log_testsuite).
-    log_testsuite = f"{args.work}/log_testsuite.txt"
     if os.path.exists(log_testsuite):
         cmd += [log_testsuite]
 
@@ -559,14 +552,6 @@ def log(args):
     pmb.helpers.run.user(args, cmd, output="tui")
 
 
-def log_distccd(args):
-    logpath = "/home/pmos/distccd.log"
-    if args.clear_log:
-        pmb.chroot.user(args, ["truncate", "-s", "0", logpath])
-    pmb.chroot.user(args, ["tail", "-n", args.lines, "-f", logpath],
-                    output="tui")
-
-
 def zap(args):
     pmb.chroot.zap(args, dry=args.dry, http=args.http,
                    distfiles=args.distfiles, pkgs_local=args.pkgs_local,
