@@ -97,6 +97,15 @@ def partition(args, layout, size_boot, size_reserve):
         ["set", str(layout["boot"]), "boot", "on"]
     ]
 
+    # Not strictly necessary if the device doesn't use EFI boot, but marking
+    # it as an ESP will cover all situations where the device does use EFI
+    # boot. Marking it as ESP is helpful for EFI fw when it's looking for EFI
+    # system partitions. It's assumed that setting this bit is unlikely to
+    # cause problems for other situations, like when using Legacy BIOS boot
+    # or u-boot.
+    if partition_type.lower() == "gpt":
+        commands += [["set", str(layout["boot"]), "esp", "on"]]
+
     for command in commands:
         pmb.chroot.root(args, ["parted", "-s", "/dev/install"] +
                         command, check=False)
@@ -112,7 +121,7 @@ def partition_cgpt(args, layout, size_boot, size_reserve):
     :param size_reserve: empty partition between root and boot in MiB (pma#463)
     """
 
-    pmb.chroot.root(args, ["apk", "add", "cgpt"])
+    pmb.chroot.apk.install(args, ["cgpt"], build=False)
 
     cgpt = {
         'kpart_start': args.deviceinfo["cgpt_kpart_start"],
@@ -136,27 +145,6 @@ def partition_cgpt(args, layout, size_boot, size_reserve):
     commands = [
         ["parted", "-s", "/dev/install", "mktable", "gpt"],
         ["cgpt", "create", "/dev/install"],
-        [
-            "cgpt", "add",
-            # pmOS_boot is second partition, the first will be ChromeOS kernel
-            # partition
-            "-i", str(layout["boot"]),  # Partition number
-            "-t", "data",
-            "-b", boot_part_start,
-            "-s", s_boot,
-            "-l", "pmOS_boot",
-            "/dev/install"
-        ],
-        # Mark this partition as bootable for u-boot
-        [
-            "parted",
-            "-s", "/dev/install",
-            "set", str(layout["boot"]),
-            "boot", "on"
-        ],
-        # For some reason cgpt switches all flags to 0 after marking
-        # any partition as bootable, so create ChromeOS kernel partition
-        # only after pmOS_boot is created and marked as bootable
         [
             "cgpt", "add",
             "-i", str(layout["kernel"]),
@@ -169,11 +157,23 @@ def partition_cgpt(args, layout, size_boot, size_reserve):
             "-P", "10",  # Priority flag
             "/dev/install"
         ],
+        [
+            "cgpt", "add",
+            # pmOS_boot is second partition, the first will be ChromeOS kernel
+            # partition
+            "-i", str(layout["boot"]),  # Partition number
+            "-t", "efi", # Mark this partition as bootable for u-boot
+            "-b", boot_part_start,
+            "-s", s_boot,
+            "-l", "pmOS_boot",
+            "/dev/install"
+        ],
     ]
 
     dev_size = pmb.chroot.root(
         args, ["blockdev", "--getsz", "/dev/install"], output_return=True)
-    root_size = str(int(dev_size) - int(s_root_start) - 1024)
+    # 33: Sec GPT table (32) + Sec GPT header (1)
+    root_size = str(int(dev_size) - int(s_root_start) - 33)
 
     commands += [
         [
