@@ -9,6 +9,7 @@ import shutil
 import sys
 
 import pmb_test  # noqa
+import pmb_test.git
 import pmb.build
 import pmb.build._package
 import pmb.config
@@ -56,7 +57,7 @@ def args_patched(monkeypatch, argv):
     return pmb.parse.arguments()
 
 
-def test_skip_already_built():
+def test_skip_already_built(args):
     func = pmb.build._package.skip_already_built
     assert pmb.helpers.other.cache["built"] == {}
     assert func("test-package", "armhf") is False
@@ -177,16 +178,16 @@ def test_build_depends_no_binary_error(args, monkeypatch):
 def test_build_depends_binary_outdated(args, monkeypatch):
     """ pmbootstrap runs with --no-depends and dependency binary package is
         outdated (#1895) """
-    # Override pmb.parse.apkindex.package(): pretend hello-world is missing
-    # and binutils-aarch64 is outdated
+    # Override pmb.parse.apkindex.package(): pretend hello-world-wrapper is
+    # missing and hello-world is outdated
     func_orig = pmb.parse.apkindex.package
 
     def func_patch(args, package, *args2, **kwargs):
         print(f"func_patch: called for package: {package}")
-        if package == "hello-world":
+        if package == "hello-world-wrapper":
             print("pretending that it does not exist")
             return None
-        if package == "binutils-aarch64":
+        if package == "hello-world":
             print("pretending that it is outdated")
             ret = func_orig(args, package, *args2, **kwargs)
             ret["version"] = "0-r0"
@@ -194,15 +195,15 @@ def test_build_depends_binary_outdated(args, monkeypatch):
         return func_orig(args, package, *args2, **kwargs)
     monkeypatch.setattr(pmb.parse.apkindex, "package", func_patch)
 
-    # Build hello-world with --no-depends and expect failure
+    # Build hello-world-wrapper with --no-depends and expect failure
     args.no_depends = True
-    pkgname = "hello-world"
-    arch = "aarch64"
+    pkgname = "hello-world-wrapper"
+    arch = "x86_64"
     force = False
     strict = True
     with pytest.raises(RuntimeError) as e:
         pmb.build.package(args, pkgname, arch, force, strict)
-    assert "'binutils-aarch64' of 'gcc-aarch64' is outdated" in str(e.value)
+    assert "'hello-world' of 'hello-world-wrapper' is outdated" in str(e.value)
 
 
 def test_is_necessary_warn_depends(args, monkeypatch):
@@ -233,7 +234,6 @@ def test_init_buildenv(args, monkeypatch):
     monkeypatch.setattr(pmb.build._package, "is_necessary_warn_depends",
                         return_true)
     monkeypatch.setattr(pmb.chroot.apk, "install", return_none)
-    monkeypatch.setattr(pmb.chroot.distccd, "start", return_none)
 
     # Shortcut and fake apkbuild
     func = pmb.build._package.init_buildenv
@@ -243,7 +243,6 @@ def test_init_buildenv(args, monkeypatch):
     # Build is necessary (various code paths)
     assert func(args, apkbuild, "armhf", strict=True) is True
     assert func(args, apkbuild, "armhf", cross="native") is True
-    assert func(args, apkbuild, "armhf", cross="distcc") is True
 
     # Build is not necessary (only builds dependencies)
     monkeypatch.setattr(pmb.build._package, "is_necessary_warn_depends",
@@ -292,17 +291,6 @@ def test_run_abuild(args, monkeypatch):
     cmd = ["abuild", "-D", "postmarketOS", "-d"]
     assert func(args, apkbuild, "armhf", cross="native") == (output, cmd, env)
 
-    # cross=distcc
-    (output, cmd, env) = func(args, apkbuild, "armhf", cross="distcc")
-    assert output == "armhf/test-1-r2.apk"
-    assert env["CARCH"] == "armhf"
-    assert env["GOCACHE"] == "/home/pmos/.cache/go-build"
-    assert env["CCACHE_PREFIX"] == "distcc"
-    assert env["CCACHE_PATH"] == "/usr/lib/arch-bin-masquerade/armhf:/usr/bin"
-    assert env["CCACHE_COMPILERCHECK"].startswith("string:")
-    assert env["DISTCC_HOSTS"] == "@127.0.0.1:/home/pmos/.distcc-sshd/distccd"
-    assert env["DISTCC_BACKOFF_PERIOD"] == "0"
-
 
 def test_finish(args, monkeypatch):
     # Real output path
@@ -404,7 +392,7 @@ def test_build_local_source_high_level(args, tmpdir):
 
     # aports: Add pmaports.cfg, .git
     shutil.copy(args.aports + "/pmaports.cfg", aports)
-    shutil.copytree(args.aports + "/.git", aports + "/.git")
+    pmb_test.git.copy_dotgit(args, tmpdir)
 
     # src: Copy hello-world source files
     src = tmpdir + "/src"
@@ -463,7 +451,7 @@ def test_build_abuild_leftovers(args, tmpdir):
 
     # aports: Add pmaports.cfg, .git
     shutil.copy(f"{args.aports}/pmaports.cfg", aports)
-    shutil.copytree(f"{args.aports}/.git", f"{aports}/.git")
+    pmb_test.git.copy_dotgit(args, aports)
 
     # aport: create abuild dir with broken symlink
     src = f"{aport}/src"
